; *************************************
; Catch The Cash by Tom Dalby 
; 999bytes long
; v1.0 initial release to MiniGameCompo
; *************************************
; Very simple game were you need catch as much cash as you can while avoiding the dangerous bombs.
; Watch out though things get pretty hectic the longer you play!
; Keys - o-left, p-right
; ******************
; Compiler Constants
; ******************
VAR_SPRITES EQU 8 ; number of sprites
VAR_ADDON EQU 40 ; wait between each speedup
_VL EQU 32 ; 1byte - velocity of npc sprite
_XP EQU _VL+1 ; 1byte - xpos of npc sprite
_YP EQU _XP+1 ; 1byte - ypos of npc sprite
_SP EQU _YP+1 ; 65bytes - sprite graphic + control byte
; **********
; Memory MAP
; **********
; ===============================
; $0000-$4000 - ROM (16384 bytes)
; ===============================
; =================================
; $4000-$5B00 - screen (6912 bytes)
; =================================
MEM_SCRPIX EQU $4000 ; start of screen (16384)
MEM_SCRATTR EQU $5800 ; attribute start (22528)
; ==================================================
; $5B00-$6000 - system stuff & basic (contended mem)
; ==================================================
ROM_LKEYP EQU $5C08 ; Sys var last key pressed
; ====================================================
; $6000-$8000 - usable RAM - 8192bytes (contended mem)
; ====================================================
MEM_SPRITE0 EQU $7000 ; 256ytes for each sprite, 8 sprites
; ******************************************************************
; 32 bytes 16bit screen position lookup
; 4 control bytes - velocity, xpos, ypos, type (nothing, cash, bomb)
; 64 bytes - graphic store
; 100 bytes per sprite
; ******************************************************************
MEM_SPRITEP EQU $7800 ; just 32bytes for player sprite position lookup (32bytes)
MEM_SPRITEB EQU $7900 ; 9*32, storage for all sprite clear, 8*npc,1*player (288bytes)
MEM_SPRITESTORE EQU $7B00 ; Stack pointer store (2bytes)
MEM_SCORE EQU MEM_SPRITESTORE+2 ; Score (2bytes) 0-65535
MEM_HISCORE EQU MEM_SCORE+2 ; HiScore (2bytes)
MEM_COUNTER EQU MEM_HISCORE+2 ; Counter (1byte)
MEM_SPEEDP EQU MEM_COUNTER+1 ; Speed Up Mem Pointer (2bytes)
MEM_ONSCREEN EQU MEM_SPEEDP+2 ; Sprites MEM_ONSCREEN Counter (1byte)
MEM_TABLESTART EQU $7C00 ; screen position lookup table store (512bytes)
; =====================================================
; $5CD6 - the code at 23766 for BIN2REM (contended mem)
; =====================================================
;org 23766 
org $6000
di ; 4t - disable interupts 
; *************************
; for the rom print routine
; *************************
ld a,2 ; 7t - channel 2
call $1601 ; 17t - open channel 2, to print in main area
; **********************
; screen position lookup
; **********************
ld de,MEM_SCRPIX ; 10t - de = start of screen
ld hl,MEM_TABLESTART ; 10t - hl=start of table
ld bc,$C007 ; 10t - 192 rows to complete, set c to 7 for and routine
_CREATELOOKUPTABLES_L1:
ld (hl),e ; 7t - load low byte into mem
inc h ; 4t - move to high byte table
ld (hl),d ; 7t - load high byte into mem
dec h ; 4t - back to low byte table
inc l ; 4t - next mem location
inc d ; 4t - next line (ypos+1)
ld a,d ; 4t - copy to a for test
and c ; 4t - <7?
jr nz,_CREATELOOKUPTABLES_S1 ; 12/7t - if <7 then still in char square
ld a,e ; 4t - copy low byte to a
add a,32 ; 7t - move to next line
ld e,a ; 4t - load back into low byte
jr c,_CREATELOOKUPTABLES_S1 ; 12/7t - if carried over >256 then moved quadrant
ld a,d ; 4t - load high byte to a for subtraction
sub 8 ; 7t - takeaway 8 so at first line of new quadrant
ld d,a ; 4t - load back into high byte
_CREATELOOKUPTABLES_S1:
djnz _CREATELOOKUPTABLES_L1 ;13/8t - loop over all lines
; ************************
; clear screen & variables
; ************************
_THESTART:
; **********************
; press any key to start
; **********************
ld hl,MEM_PAKTXT ; 10t - press any key text
call _PRTTXT ; 17t
ei; 4t - enable interupts
ld hl,ROM_LKEYP ; 10t - ystem variable for last key pressed
xor a ; 4t - a=0
ld (hl),a ; 7t - reset last key pressed
_GETKEY_L1:
or (hl) ; 7t - test for change
jr z,_GETKEY_L1 ; 12/7t - if no change,then read again. Once changed a=ascii of key pressed
di ; 4t - disable interupts
; **********************************
; reset speed thresholds & variables
; **********************************
xor a ; 4t - a=0 
out ($FE),a ; 11t - clear border
ld (_SMC4+1),a ; 13t - reset check later in code
ld (MEM_COUNTER),a ; 13t - reset the counter
ld h,a ; 4t
ld l,a ; 4t
ld (MEM_SCORE),hl  ; 16t - reset score
ld hl,MEM_SPDDATA+5 ; 10t
ld (MEM_SPEEDP),hl ; 16t
call _SPEEDUP ; 17t
ld a,3 ; 7t - start with 3 npc onscreen
ld (MEM_ONSCREEN),a ; 13t 
; ****************
; clear the screen
; ****************
ld hl,MEM_SCRPIX ; 10t
ld de,MEM_SCRPIX+1 ; 10t
ld (hl),0 ; 10t - paste nothing or clear the screen
ld bc,6143 ; 10t
ldir ; 21/15t
inc hl ; 6t - move on one so in correct place in attr space
inc de ; 6t
ld a,%01000111 ; 7t
ld (hl),a ; 7t -  black with white ink
ld bc,64 ; 10t
ldir ; 21/15t
ld (hl),%01000110 ; 10t - then black with yellow ink for npc sprites
ld bc,640 ; 10t
ldir ; 21/15t
ld (hl),a ; 7t - back to balck with white ink for player sprite
ld bc,63 ; 10t
ldir ; 21/15t
; ****************************************
; create random speed & positions for plot
; ****************************************
ld h,MEM_SPRITE0/256 ; 7t - move to the start
ld b,VAR_SPRITES ; 7t - x sprites
_CRSPFP_L1:
push bc ; 11t
call _NEWPOS ; 17t
inc h ; 4t - next sprite
pop bc ; 10t
djnz _CRSPFP_L1 ; 13/8t
; ***************
; player position
; ***************
ld l,_XP ; 7t
ld (hl),14 ; 10t
ld l,_YP ; 7t
ld (hl),176 ; 10t
call _SPRITEPOS ; 17t
ld (MEM_SPRITESTORE),sp ; 20t - store stack pointer
jr _SKIPCLR ; 12t
; *********
; game loop
; *********
_MAINLOOP:
; **********************
; check if score>hiscore
; **********************
ld hl,(MEM_HISCORE) ; 20t
ld de,(MEM_SCORE) ; 16t
and a ; 4t - clear carry
sbc hl,de ; 15t
jr nc,_CSGTHS_S1 ; 12/7t - if score>hiscore then update hiscore
ld hl,(MEM_SCORE) ; 16t
ld (MEM_HISCORE),hl ; 16t
_CSGTHS_S1:
; **********************
; print score & hi-score
; **********************
ld hl,(MEM_HISCORE) ; 10t
call _PRTNUM5 ; 17t
ld hl,MEM_HISCORETXT ; 10t
call _PRTTXT ; 17t
ld hl,MEM_PRTNUM5
call _PRTTXT ; 17t 
ld hl,MEM_SCORETXT ; 10t
call _PRTTXT ; 17t
ld hl,(MEM_SCORE) ; 16t
call _PRTNUM5 ; 17t
ld hl,MEM_PRTNUM5 ; 10t
call _PRTTXT ; 17t 
ld (MEM_SPRITESTORE),sp ; 20t - store stack pointer
; *****************************
; wait for scanline before plot
; *****************************
ei ; 4t
halt 
di ; 4t
; *****************
; clear npc sprites
; *****************
ld hl,MEM_SPRITEB ; 10t - starting position
ld sp,hl ; 6t - move stack pointer to sprite pos table
xor a ; 4t - a=0 
ld b,VAR_SPRITES*16 ; 7t - clear all npc, 16lines per sprite
_CNS_L1:
pop de ; 10t - get screen position
ld (de),a ; 7t - clear
inc e ; 4t
ld (de),a ; 7t
djnz _CNS_L1 ; 13/8t
; ***********************
; clear the player sprite
; ***********************
ld b,16 ; 7t
_CPS_L1:
pop de ; 10t
ld (de),a ; 7t
inc e ; 4t
ld (de),a ; 7t
inc e ; 4t
ld (de),a ; 7t
djnz _CPS_L1 ; 13/8t
; ****************
; plot all sprites
; ****************
_SKIPCLR:
; ****************
; first the player
; ****************
ld hl,MEM_SPRITEP ; 10t
ld sp,hl ; 6t - move stack pointer
ld hl,MEM_HANDGR ; 10t - graphic
ld b,16 ; 7t
_PPS_L1:
pop de ; 10t
ldi ; 16t
ldi ; 16t
ldi ; 16t
djnz _PPS_L1 ; 13/8t
; **************************
; then the gold/bomb/nothing
; **************************
ld h,MEM_SPRITE0/256 ; 7t - starting position
ld c,VAR_SPRITES ; 7t - number of npc sprites to plot
_PNS_L1:
ld l,0 ; 7t
ld sp,hl ; 6t - move stack pointer to sprite pos table
ld l,_SP ; 7t
ld a,(hl) ; 7t
or a ; 4t
jr z,_PNS_S1 ; 12/7t - if 0 then don't plot anything
inc l ; 4t
ld b,16 ; 7t - set loop counter
_PNS_L2:
pop de ; 10t - get screen pos
ld a,(de) ; 7t
and (hl) ; 7t - apply mask
inc l ; 4t
or (hl) ; 7t - apply sprite
inc l ; 4t
ld (de),a ; 7t - paste to screen
inc e ; 4t - next screen pos
ld a,(de) ; 7t
and (hl) ; 7t
inc l ; 4t
or (hl) ; 7t
inc l ; 4t
ld (de),a ; 7t
djnz _PNS_L2 ; 13/8t
_PNS_S1:
inc h ; 4t - next npc sprite
dec c ; 4t 
jr nz,_PNS_L1 ; 12/7t
ld sp,(MEM_SPRITESTORE) ; 20t - restore stack pointer
; *************************
; create buffer before move
; *************************
ld hl,MEM_SPRITE0 ; 10t
ld de,MEM_SPRITEB ; 10t
ld b,VAR_SPRITES+1 ; 7t
xor a ; 4t
_CBF_L1:
push bc ; 11t
ld bc,32 ; 10t
ldir ; 21/15t
inc h ; 4t
ld l,a ; 4t - reset hl & move to next one
pop bc ; 10t
djnz _CBF_L1 ; 13/8t
; *******************************
; wait for scanline to keep 25fps
; *******************************
ei ; 4t
halt 
di ; 4t
; *************
; move npc down
; *************
ld h,MEM_SPRITE0/256 ; 7t 
ld b,VAR_SPRITES ; 7t - move all npc sprites
_MNS_L1:
push bc ; 11t
ld l,_YP ; 7t
ld a,(hl) ; 7t - get ypos
cp 168 ; 7t
jr c,_MNS_S1 ; 12/7t - if a<168 the don't bother checking anything
cp 176 ; 7t
jr z,_MNS_S2 ; 12/7t - if at the end of screen then loop to top
; ********************
; catch for check here
; ********************
ld l,_SP ; 7t
ld a,(hl) ; 7t
or a ; 4t
jr z,_MNS_S1 ; 12/7t - if not an active sprite then nothing to check
ld de,MEM_SPRITEP+_XP ; 10t
ld a,(de) ; 7t - get player position
dec a ; 4t - back one so capturing rhs of npc sprite
ld l,_XP ; 7t
ld c,(hl) ; 7t - get npc sprite position
ld b,4 ; 7t - check all 4 positions
_MNS_L2:
cp c ; 7t
jr z,_MNS_S3 ; 12/7t - if a match then a catch
inc a ; 4t - try next xpos
djnz _MNS_L2 ; 13/8t
jr _MNS_S1 ; 12t - nothing found
; ****************
; something caught
; ****************
_MNS_S3:
ld l,_SP ; 7t
ld a,(hl) ; 7t
cp 1 ; 7t
jr z,_MNS_S4 ; 12/7t - if npc type 1 then cash so add 1
; *************
; whoops a bomb
; *************
ld b,255 ; 7t - make an crash sound
_MNS_L3:
push bc ; 11t
call _RANDNO ; 17t
ld b,2 ; 7t
ld c,a ; 4t
call _BEEP ; 17t
pop bc ; 10t
djnz _MNS_L3 ; 13/8t
jp _THESTART ; 10t - dead so back to the start again
; *************
; got some cash
; *************
_MNS_S4:
ld bc,$8012 ; 10t - ping sound
call _BEEP ; 17t
push hl ; 11t
ld hl,(MEM_SCORE) ; 16t
inc hl ; 6t - add one to the score
ld (MEM_SCORE),hl ; 16t
pop hl ; 10t
_MNS_S2:
ld l,_SP ; 7t
ld a,(hl) ; 7t
or a ; 4t
jr z,_MNS_S5 ; 12/7t - if a blank then don't reset
push hl ; 11t
ld hl,MEM_ONSCREEN ; 10t
inc (hl) ; 11t - add one back in as need to replace
pop hl ; 10t
_MNS_S5:
call _NEWPOS ; 17t
ld a,(_SMC4+1) ; 13t - get current counter check
cp VAR_ADDON*6 ; 7t - if maxed out then no more speed updates
jr z,_MNS_S6 ; 12/7t
ld a,(MEM_COUNTER) ; 13t - get counter and update
inc a ; 4t
_SMC4:
cp 0 ; 7t
jr nz,_MNS_S7 ; 12/7t - if not a counter check then no speed update
push hl ; 11t
ld hl,(MEM_SPEEDP) ; 16t - get current multiplier memory pointer
dec hl ; 6t
ld (MEM_SPEEDP),hl ; 16t - paste back
call _SPEEDUP ; 17t
ld hl,MEM_ONSCREEN ; 10t
inc (hl) ; 11t - add one more npc sprite (max 8)
pop hl ; 10t
xor a ; 4t - reset counter
_MNS_S7:
ld (MEM_COUNTER),a  ; 13t
jr _MNS_S6 ; 12t
_MNS_S1:
ld l,_VL ; 7t
ld c,(hl) ; 7t - set c to velocity
ld l,_YP ; 7t
ld a,(hl) ; 7t - get ypos
add a,c ; 4t- add velocity to ypos
ld (hl),a ; 7t - store new ypos
; **********************************************
; sort out old positions - copy start+v to start
; **********************************************
rlc c ; 8t - velocity now 2,4 or 8 for add
ld e,0 ; 7t - reset - ensure de=start,hl=start+velocity
ld b,e ; 4t - reset for loop
ld d,h ; 4t - set to h
ld l,c ; 4t - set l to start+velocityx2
ld a,32 ; 7t - start with 32 positions
sub c ; 4t -  a=30,28 or 24
ld c,a ; 4t - copy for loop
ldir ; 21/16t - copy 32-vx2 times -> de=end-v*2,hl=end max
; *************************************************
; last 1,2 or 4 -> de in correct position for this
; *************************************************
rrca ; 4t - /2 so now a = 15 for 1,14 for 2 or 12 for 4
ld l,_YP ; 7t
add a,(hl) ; 7t - add ypos
ld l,_VL ; 7t
ld b,(hl) ; 7t - get velocity for loop
ld l,_XP ; 7t
ld c,(hl) ; 7t - grab xpos 
ld l,e ; 4t - load e into l for routine (makes hl=de)
ld e,a ; 4t - put new ypos into e for routine
ld d,MEM_TABLESTART/256 ; 7t - set table high byte
_MNS_L4:
ld a,(de) ; 7t - get screen low byte
add a,c ; 4t - add xpos to low byte 
ld (hl),a ; 7t - put low byte into mem
inc l ; 4t
inc d ; 4t - move to high byte lookup
ld a,(de) ; 7t - get screen high byte
ld (hl),a ; 7t - put high byte into mem
inc l ; 4t
inc e ; 4t - next line (ypos+1)
dec d ; 4t
djnz _MNS_L4 ; 13/8t
_MNS_S6:
inc h ; 4t - next sprite
pop bc ; 10t
dec b ; 4t
jp nz,_MNS_L1 ; 10t - loop
; *************************************
; now move the player so check keyboard
; *************************************
ld hl,MEM_SPRITEP+_XP ; 10t
ld a,%11011111 ; 7t - scan yuiop
in a,($FE) ; 7t
cpl ; 4t
and %00000011 ; 7t
cp %00000010 ; 7t - o pressed? - left
jp nz,_MPS_S1 ; 10t
ld a,(hl) ; 7t - get xpos
or a ; 4t - a=0?
jr z,_MPS_S2 ; 12/7t - if zero then don't move left anymore
dec (hl) ; 11t - xpos=xpos-1
ld l,0 ; 7t - reset l
ld b,16 ; 7t - 24 lines to update (354t)
_MPS_L1:
dec (hl) ; 11t - takeaway one
inc l ; 4t - move to next
inc l ; 4t
djnz _MPS_L1 ; 13/8t
ld bc,$0202 ; 10t
call _BEEP ; 17t - small click to acknowledge movement
jr _MPS_S2 ; 12t
_MPS_S1:
cp %00000001 ; 7t - p pressed? - right
jr nz,_MPS_S2 ; 12/7t
ld a,(hl) ; 7t
cp 29 ; 7t - 29 then end of screen to the right
jr z,_MPS_S2 ; 12/7t
inc (hl) ; 11t - xpos=xpos+1
ld l,0 ; 7t - reset l
ld b,16 ; 7t - 24 lines to update (354t)
_MPS_L2:
inc (hl) ; 11t - add one
inc l ; 4t - move to next
inc l ; 4t
djnz _MPS_L2 ; 13/8t
ld bc,$0202 ; 10t
call _BEEP ; 17t - small click to acknowledge movement
_MPS_S2:
jp _MAINLOOP ; 10t - back to top

; ============================
; _BEEP - Basic Beeper Routine
; input - b-loop,c-wait
; output - beep
; ============================
_BEEP:
xor a ; 4t - clear a to retain black border
_BEEP_L1:
xor %00011000 ; 7t - flip bits 3 & 4
out ($FE),a ; 11t
ld d,b ; 4t
ld b,c ; 4t
_BEEP_L2:
djnz _BEEP_L2 ; 13/8t - wait
ld b,d ; 4t
djnz _BEEP_L1 ; 13/8t - loop to create wave
ret ; 10t

; =============================================
; _NEWPOS - select a new position for the object
; input - h-hi byte of sprite
; output - none
; =============================================
_NEWPOS:
call _RANDNO ; 17t - get random number
and 31 ; 7t - 0-31
cp 31 ; 7t
jr nz,_NEWPOS_S1 ; 12/7t - if at 31 then reduce by one to fit sprite on screen
dec a ; 4t
_NEWPOS_S1:
ld l,_XP ; 7t
ld (hl),a ; 7t - xpos
ld l,_YP ; 7t
ld (hl),16 ; 7t - ypos always at the top
call _SPRITEPOS ; 17t - set-up sprite positions
call _RANDNO ; 17t
ld b,1 ; 7t - starting velocity
_SMC0:
cp 0 ; 7t - self modifying
jr c,_NEWPOS_S2 ; 12/7t - if < then velocity at 1
inc b ; 4t - veloity now 2
_SMC1: ; adjust these to make the cash faster
cp 0 ; 7t
jr c,_NEWPOS_S2 ; 12/7t - if < then velocity at 2
rl b ; 8t - velocity now 4
_SMC2:
cp 0 ; 7g
jr c,_NEWPOS_S2 ; 12/7t - if < then velocity at 4
rl b ; 7t - 8 - if none then velocity = 8 
_NEWPOS_S2:
ld l,_VL ; 7t
ld (hl),b ; 7t - set the velocity in sprite control
; ************************************
; check if used all npc sprites or not
; ************************************
ld a,(MEM_ONSCREEN) ; 13t
or a ; 4t - a=0?
jr z,_NEWPOS_S3 ; 12/7t
dec a ; 4t
ld (MEM_ONSCREEN),a ; 13t
call _RANDNO ; 17t - another one this time for sprite type
ex de,hl ; 4t - swap for routine
ld e,_SP ; 7t
ld hl,MEM_MONEYGR ; 10t
_SMC3:
cp 128 ; 7t
jr c,_NEWPOS_S4 ; 12/7t - if <128 then cash otherwise bomb
ld hl,MEM_BOMBGR ; 10t
_NEWPOS_S4:
ld bc,65 ; 10t
ldir ; 21/15t - copy all the sprite data to npc control buffer
ex de,hl ; 4t
ret ; 10t
_NEWPOS_S3:
ld l,_SP ; 7t
ld (hl),a ; 7t - set control byte to 0 or nothing
ret ; 10t
MEM_SPDDATA:
defb 2,4,8,16,32,64,128,192

; =================================================================================
; _SPEEDUP - simple routine to load predefined thresholds into code to give speedup
; input - hl-lookup table mem pointer
; output - none
; =================================================================================
_SPEEDUP:
ld a,(hl) ; 7t
ld (_SMC0+1),a ; 13t - load velocity 1 threshold
inc hl ; 6t
ld a,(hl) ; 7t
ld (_SMC1+1),a ; 13t - load velocity 2 threshold
inc hl ; 6t
ld a,(hl) ; 7t
ld (_SMC2+1),a ; 13t - load velocity 4 threshold
ld a,(_SMC4+1) ; 13t
add a,VAR_ADDON ; 7t
ld (_SMC4+1),a ; 13t - update speedup check threshold
ret ; 10t

; ===========================================
; _RANDNO - very basic random number, period 256
; input - none
; output - a=random number between 0 and 255
; ===========================================
_RANDNO:
ld a,0 ; 7t
ld d,a ; 4t
add a,a ; 4t
add a,a ; 4t
add a,d ; 4t
inc a ; 4t
ld (_RANDNO+1),a ; 13t
ret ; 10t

; ========================================================
; _PRTNUM5 - Convert number to ASCII string (00000 format)
; input-hl=16bit number to print
; output-none
; ========================================================
_PRTNUM5:
ld de,MEM_PRTNUM5 ; 10t
ld bc,-10000 ; 10t
call _PRTNUM5_S1 ; 17t
ld bc,-1000 ; 10t
call _PRTNUM5_S1 ; 17t
ld bc,-100 ; 10t
call _PRTNUM5_S1 ; 17t
ld bc,-10 ; 10t
call _PRTNUM5_S1 ; 17t
ld a,"0" ; 7t
add a,l ; 4t
ld (de),a ; 7t
ret ; 10t
_PRTNUM5_S1:
ld a,"0"-1 ; 7t
_PRTNUM5_S2:
inc a ; 4t - add one for each loop
add hl,bc ; 11t
jr c,_PRTNUM5_S2 ; 12/7t - when no carry a=correct number for that place
sbc hl,bc ; 15t - take one off
ld (de),a ; 7t - copy to txt buffer
inc de ; 5t - next txt buffer pos
ret ; 10t
MEM_PRTNUM5:
defb 0,0,0,0,0,$FF
MEM_SCORETXT:
defb 22,0,0,"CASH ",$60,$FF
MEM_HISCORETXT:
defb 22,0,23,16,7,17,0,19,1,"HI ",$60,$FF
MEM_PAKTXT:
defb 22,11,9,"PRESS ANY KEY",$FF

; =============================================
; _PRTTXT - Very simple ROM based print routine
; input - hl=text to print
; output - none
; =============================================
_PRTTXT: 
ld a,(hl) ; 7t - get char
cp $FF ; 7t - end marker?
ret z ; 11/5t
rst 16 ; 11t - ROM routine to do the actual print
inc hl ; 6t - move to next character
jr _PRTTXT ; 12t

; =========================================================
; _SPRITEPOS - Build 16lines of Screen pos from given start
; input - h=sprite hi byte
; output - none
; =========================================================
_SPRITEPOS:
ld l,_YP ; 7t
ld e,(hl) ; 7t
ld l,_XP ; 7t
ld c,(hl) ; 7t
ld b,16 ; 7t - 16 lines
ld l,0 ; 7t - reset l
ld d,MEM_TABLESTART/256 ; 7t - set table high byte
_SPRITEPOS_L1:
ld a,(de) ; 7t - get screen low byte
add a,c ; 4t - add xpos to low byte 
ld (hl),a ; 7t - put low byte into mem
inc l ; 4t
inc d ; 4t - move to high byte lookup
ld a,(de) ; 7t - get screen high byte
ld (hl),a ; 7t - put high byte into mem
inc l ; 4t
dec d ; 4t - back to low byte
inc e ; 4t - next line (ypos+1)
djnz _SPRITEPOS_L1 ; 13/8t (1550t)
ret ; 10t - return

MEM_MONEYGR: ;(65bytes)
	defb 1
	DEFB	240,  0, 63,  0,224, 15, 31,192
	DEFB	208,  7, 31,192,128, 39, 63,128
	DEFB	  0,121, 63,  0,  0, 71, 31,192
	DEFB	128, 31, 15,224,128, 56,  7,112
	DEFB	  0,115,  3, 56,  0,115,  1,252
	DEFB	  0,120,  0,254,  0,113,  0,254
	DEFB	  0,120,  0, 62,128, 49,  1,252
	DEFB	192, 31,  3,240,224,  0, 15,  0
MEM_BOMBGR: ;(65bytes)
	defb 2
	DEFB	248,  0, 35,  0,224,  7,  1,220
	DEFB	192, 24,  0, 34,128, 32,  0, 66
	DEFB	  0, 76,  1,140,  0, 88,  1,148
	DEFB	  0,144,  1,100,  0,128,  1,  4
	DEFB	  0,128,  1,  4,  0,128,  1,  4
	DEFB	  0, 64,  3,  8,  0, 64,  3,  8
	DEFB	128, 32,  7, 16,192, 24, 15, 96
	DEFB	224,  7, 31,128,248,  0,127,  0
MEM_HANDGR: ;(48bytes)
	DEFB	  6, 76,128,  9,179, 64, 22,179
	DEFB	 64, 54,179, 64, 75, 89,160,179
	DEFB	157,160,177,198, 28, 92,217,226
	DEFB	 47, 63,157, 19,  6,126, 12,217
	DEFB	254,  2,223,254,  1, 31,158,  0
	DEFB	206,126,  0, 49,249,  0, 14,  6

